<?php
namespace FiloBlu\Rma\Handlers;
use FiloBlu\Rma\Helper\EasyReturnHelper;
use Magento\Framework\App\RequestInterface;
use FiloBlu\Rma\Api\EasyReturnRepositoryInterface;
use FiloBlu\Rma\Api\Data\EasyReturnInterface;
use Magento\Catalog\Api\ProductRepositoryInterface;
use Psr\Log\LoggerInterface;

class EasyReturnHandler
{
    /**
     * @var EasyReturnHelper
     */
    private $easyReturnHelper;
    /**
     * @var RequestInterface
     */
    private $request;
    /**
     * @var EasyReturnRepositoryInterface
     */
    private $easyReturnRepository;
    /**
     * @var EasyReturnInterface
     */
    private $easyReturnInterface;
    /**
     * @var ProductRepositoryInterface
     */
    private $productRepository;
    /**
     * @var LoggerInterface
     */
    private $logger;

    /**
     * EasyReturnHandler constructor.
     * @param EasyReturnHelper $easyReturnHelper
     * @param RequestInterface $request
     * @param EasyReturnRepositoryInterface $easyReturnRepository
     * @param EasyReturnInterface $easyReturnInterface
     * @param ProductRepositoryInterface $productRepository
     * @param LoggerInterface $logger
     */
    public function __construct(
        EasyReturnHelper $easyReturnHelper,
        RequestInterface $request,
        EasyReturnRepositoryInterface $easyReturnRepository,
        EasyReturnInterface $easyReturnInterface,
        ProductRepositoryInterface $productRepository,
        LoggerInterface $logger)
    {
        $this->easyReturnHelper = $easyReturnHelper;
        $this->request = $request;
        $this->easyReturnRepository = $easyReturnRepository;
        $this->easyReturnInterface = $easyReturnInterface;
        $this->productRepository = $productRepository;
        $this->logger = $logger;
    }


    /**
     * @param \Magento\Rma\Model\Rma $subject
     * @param $result
     */
    public function saveEasyReturnFields(\Magento\Rma\Model\Rma $subject, $result){
        try{
            if($this->easyReturnHelper->isEasyReturnEnabled($subject->getStoreId())){
                $formData = $this->request->getParams();
                if($result->getExtensionAttributes()->getEasyReturn())
                {
                    $formData['filoblu_simple_rma'] = "on";
                    foreach ($result->getExtensionAttributes()->getPickUpAddress()->getData() as $k => $val){
                      $formData[$k]= $val;
                    }
                    $formData['customer_firstname'] = $result->getExtensionAttributes()->getPickUpAddress()['firstname'];
                    $formData['customer_lastname'] = $result->getExtensionAttributes()->getPickUpAddress()['lastname'];
                }
                if(isset($formData['filoblu_simple_rma']) && $formData['filoblu_simple_rma'] == "on"){
                    $formData['rma_entity_id'] = $subject->getEntityId();
                    $formData['weight'] = 0;
                    foreach ($result->getItems() as $k => $rmaItem){
                        $formData['weight'] += $rmaItem->getQtyRequested() * $this->productRepository->getById($rmaItem->getEntityId())->getWeight();
                    }
                    $formData['store'] = $subject->getOrder()->getStore();
                    $easyReturnRepository = $this->easyReturnRepository;
                    $easyReturn = $this->easyReturnInterface->setEasyReturnData($formData);
                    $easyReturnRepository->save($easyReturn);
                }
            }
        }catch (\Exception $e){
            $this->logger->critical($e->getMessage());
        }catch (\Throwable $t){
            $this->logger->critical($t->getMessage());
        }

    }

}